/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation.condition.parameter.definitions;

import static com.google.common.base.MoreObjects.toStringHelper;

import java.util.Objects;

import org.onosproject.nemo.model.common.ParameterName;

/**
 * The key to condition parameter definition.
 */
public class ConditionParameterDefinitionKey {

    private final ParameterName parameterName;

    /**
     * Creates a condition parameter definition from a given parameter name.
     *
     * @param parameterName the parameter name
     */
    public ConditionParameterDefinitionKey(ParameterName parameterName) {
        this.parameterName = parameterName;
    }

    /**
     * Creates a copy from a given condition parameter definition key.
     *
     * @param key the condition parameter definition key
     */
    public ConditionParameterDefinitionKey(
            ConditionParameterDefinitionKey key) {
        parameterName = key.parameterName;
    }

    /**
     * Returns the parameter name of this instance.
     *
     * @return the parameter name
     */
    public ParameterName getParameterName() {
        return parameterName;
    }

    @Override
    public int hashCode() {
        return parameterName.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        ConditionParameterDefinitionKey other =
                (ConditionParameterDefinitionKey) obj;
        return Objects.equals(parameterName, other.parameterName);
    }

    @Override
    public String toString() {
        return toStringHelper(this)
                .add("parameterName", parameterName)
                .toString();
    }
}